@@ -77,18 +77,21 @@ def iterative_convex_hull_method(A, B, y_min, y_max, tol, P = None, bias = None,
     nB,L = B.shape
     #L = len(y_min)
     if n != nB:
-        raise ValueError('Matrix A and B must have same number fo rows. In your case A: {}, B: {} '.format(A.shape,B.shape))
+        raise ValueError('ICHM: Matrix A and B must have same number fo rows. In your case A: {}, B: {} '.format(A.shape,B.shape))
 
     if m > n or n > L :
-        raise ValueError('Matrix A and B dimensions must be colB >= rowB = rowA >= colA. In your case A: {}, B: {} '.format(A.shape,B.shape))
+        raise ValueError('ICHM: Matrix A and B dimensions must be colB >= rowB = rowA >= colA. In your case A: {}, B: {} '.format(A.shape,B.shape))
 
     if L!= len(y_max) or L!= len(y_min):
-        raise ValueError('Limits dimensios are not valid, should have {:d} entries. In your case y_min:{} and y_max:{}'.format(L,len(y_min),len(y_max)))
+        raise ValueError('ICHM: Limits dimensios are not valid, should have {:d} entries. In your case y_min:{} and y_max:{}'.format(L,len(y_min),len(y_max)))
 
 
     y_min = np.array(y_min).reshape((-1,))
     y_max = np.array(y_max).reshape((-1,))
 
+    if np.min(y_max - y_min) < 0:
+        raise ValueError('ICHM: Limits not valid, minimal value is higher than maximal value.')
+
     u, s, v = np.linalg.svd(A.T)
     r = len(s)
     V1 = np.array(v.transpose()[:,:r])
@@ -131,7 +134,7 @@ def iterative_convex_hull_method(A, B, y_min, y_max, tol, P = None, bias = None,
         # check the size
         nP, mP = P.shape
         if mP != m or nP > mP:
-            raise ValueError('Matrix P dimensions error - (rows,cols) = P.shape should be: rows > cols and cols = {:d}. In your case P.shape = {}.'.format(m,P.shape))
+            raise ValueError('ICHM: Matrix P dimensions error - (rows,cols) = P.shape should be: rows > cols and cols = {:d}. In your case P.shape = {}.'.format(m,P.shape))
         M = P.dot(M)
         x_bias = P.dot(x_bias)
         u = P.dot(u)  
@@ -140,9 +143,9 @@ def iterative_convex_hull_method(A, B, y_min, y_max, tol, P = None, bias = None,
         # check the size
         nG, mG = G_in.shape
         if mG != L:
-            raise ValueError('Matrix G_in dimensions error - (rows,cols) = G_in.shape should be: col = {:d}. In your case G_in.shape = {}.'.format(L,G_in.shape))
+            raise ValueError('ICHM: Matrix G_in dimensions error - (rows,cols) = G_in.shape should be: col = {:d}. In your case G_in.shape = {}.'.format(L,G_in.shape))
         if nG != len(h_in):
-            raise ValueError('Vector h_in dimensions error - should have {:d} entries. In your case h_in.shape = {}.'.format(nG,len(h_in)))    
+            raise ValueError('ICHM: Vector h_in dimensions error - should have {:d} entries. In your case h_in.shape = {}.'.format(nG,len(h_in)))    
 
         G = matrix(np.vstack((-np.identity(L),np.identity(L),G_in)))
         h = matrix(np.hstack((list(-np.array(y_min)),y_max, h_in)))
@@ -174,10 +177,10 @@ def iterative_convex_hull_method(A, B, y_min, y_max, tol, P = None, bias = None,
         linprog_count = linprog_count + 2
         c = matrix((u[:,i].T).dot(M))
         res = cvxopt.glpk.lp(c=-c,  A=Aeq, b=beq, G=G,h=h, options=solvers_opt)
-        if res[1]:
+        if res[1] is not None:
             y_vert = stack(y_vert, res[1],'h')
         res = cvxopt.glpk.lp(c=c,  A=Aeq, b=beq, G=G,h=h, options=solvers_opt)
-        if res[1]:
+        if res[1] is not None:
             y_vert = stack(y_vert, res[1],'h')
     x_p  = M.dot(y_vert) + x_bias
     z_vert = B.dot(y_vert) + bias
@@ -190,6 +193,7 @@ def iterative_convex_hull_method(A, B, y_min, y_max, tol, P = None, bias = None,
     try:
         hull = ConvexHull(x_p.T, incremental=True)
     except:
+        print("ICHM: Convex hull issue at init - continuing with a QJ option!")
         try:
             hull = ConvexHull(x_p.T, incremental=True, qhull_options="QJ")
         except:
@@ -211,7 +215,6 @@ def iterative_convex_hull_method(A, B, y_min, y_max, tol, P = None, bias = None,
         x_center = np.mean(x_p,axis=1)
         
         y_vert_new = []
-
         max_delta = 0
         for face, equation in zip(hull.simplices,hull.equations):
             
@@ -221,7 +224,7 @@ def iterative_convex_hull_method(A, B, y_min, y_max, tol, P = None, bias = None,
             face_key = str(np.sort(equation))
             # check if this face (face index) has been found as final
             if face_key in face_final.keys():
-                continue; 
+                continue;
             
             # update linprog counter
             linprog_count = linprog_count + 1
@@ -245,6 +248,7 @@ def iterative_convex_hull_method(A, B, y_min, y_max, tol, P = None, bias = None,
 
             # vertex distance from the face
             distance = np.abs( face_normal.dot( M.dot(res) + x_bias) -face_normal.dot( x_p[:,face[0]] ))
+
             if distance > tol:
                 # new vertex found
                 y_vert_new = stack(y_vert_new, res, 'h')
@@ -256,16 +260,19 @@ def iterative_convex_hull_method(A, B, y_min, y_max, tol, P = None, bias = None,
 
         if len(y_vert_new):
             x_p_new = M.dot(y_vert_new) + x_bias
-            try:
-                hull.add_points(x_p_new.T)
-            except:
-                hull = ConvexHull(x_p.T, incremental=True, qhull_options="QJ")
-            
-            y_vert = stack(y_vert, y_vert_new,'h')
+
             x_p  = stack(x_p, x_p_new,'h')
+            y_vert = stack(y_vert, y_vert_new,'h')
 
             z_new = B.dot(y_vert_new) + bias
             z_vert = stack(z_vert, z_new,'h')
+
+            try:
+                hull.add_points(x_p_new.T)
+            except:
+                print("ICHM: Convex hull issue - continuing with a QJ option!")
+                hull = ConvexHull(x_p.T, incremental=True, qhull_options="QJ")
+            
         elif max_delta > tol: 
             print("ICHM: Search stopped prematurely - search stuck at precision: {}!".format(max_delta))
             # raise error here instead
@@ -512,8 +519,18 @@ def hsapce_to_vertex(H,d):
         feasible_point = chebyshev_center(H,d)
 
         # calculate the convex hull
-        hd = HalfspaceIntersection(hd_mat,feasible_point,'QJ')
-        hull = ConvexHull(hd.intersections)
+        try:
+            hd = HalfspaceIntersection(hd_mat,feasible_point)
+            hull = ConvexHull(hd.intersections)
+        except:
+            print("H2V: Convex hull issue: using QJ option! ")
+            try:
+                hd = HalfspaceIntersection(hd_mat,feasible_point,qhull_options='QJ')
+                hull = ConvexHull(hd.intersections)
+            except:
+                print("H2V: Convex hull issue: using Q0 option! ")
+                hd = HalfspaceIntersection(hd_mat,feasible_point,qhull_options='Q0')
+                hull = ConvexHull(hd.intersections)
         return hd.intersections.T, hull.simplices
 
 def vertex_to_faces(vertex):
